multidim.PointCloud.unique_with_multiplicity — GDA Toolbox v1.0 Manual

# multidim.PointCloud.unique_with_multiplicity

`PointCloud.` `unique_with_multiplicity`()

  Look for duplicate points, and mark their multiplicity. This sets self.multiplicity

  ToDo: Use Covertree.

  Examples

      >>> a = np.array([[5.0, 2.0], [3.0, 4.0], [5.0, 2.0]])
      >>> pc = PointCloud(a)
      >>> b, counts = pc.unique_with_multiplicity()
      >>> print(b)
      [[ 3.  4.]
       [ 5.  2.]]
      >>> print(counts)
      [1 2]

#### Previous topic

multidim.PointCloud.sever

#### Next topic

multidim.PointCloud.witnessed_barycenters